==> phpnuke-5.5.tgz: www/phpnuke/html/modules/Reviews/language/lang-brazilian.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please sent to me (fbc@mandrakesoft.com)    */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_PREVIOUS","Pgina Anterior");
define("_NEXT","Pgina Posterior");
define("_YOURNAME","Seu Nome");
define("_SORTASC","Ordem Crescente");
define("_SORTDESC","Ordem Decrescente");
define("_CANCEL","Cancela");
define("_YES","Sim");
define("_NO","No");
define("_SCORE","Pontos:");
define("_REPLYMAIN","Enviar Comentrio");
define("_ALLOWEDHTML","HTML Permitido:");
define("_POSTANON","Enviar como Annimo");
define("_WRITEREVIEW","Escreva uma Reviso");
define("_WRITEREVIEWFOR","Escreva uma Reviso para");
define("_ENTERINFO","Por favor entre com as informaes de acordo com as especificaes");
define("_PRODUCTTITLE","Ttulo do Produto");
define("_NAMEPRODUCT","Nome do Produto Revisado.");
define("_REVIEW","Reviso");
define("_CHECKREVIEW","Sua Reviso atual. Por favor observe a gramtica correta! Faa isto com pelo menos 100 palavras, OK? Voc pode usar cdigo HTML e suas codificaes se souber usar.");
define("_FULLNAMEREQ","Seu Nome Completo. Obrigatrio.");
define("_REMAIL","Seu Email");
define("_REMAILREQ","Seu Endereo de Email . Obrigatrio.");
define("_SELECTSCORE","Pontuao deste Produto");
define("_RELATEDLINK","Link Relacionado");
define("_PRODUCTSITE","Website oficial do produto. Confira se o endereo comea mesmo com \"http://\"");
define("_LINKTITLE","Ttulo do Link ");
define("_LINKTITLEREQ","Requirido se voc tem um site relacionado, caso contrrio  opcional.");
define("_RIMAGEFILE","Nome da Figura");
define("_RIMAGEFILEREQ","Nome da imagem correspondente, localizada em images/reviews. No Obrigatrio");
define("_CHECKINFO","Por favor tenha certeza que a informao que voc entrou  100% correta e esta com a gramtica correta. Por exemplo, por favor no exagere com seu texto ou ele ser rejeitado.");
define("_INVALIDTITLE","Ttulo Invlido...No pode estar em branco");
define("_INVALIDSCORE","Pontuao Invlida...Deve ser entre 1 e 10");
define("_INVALIDTEXT","Texto Reviso Invlido...No pode estar em branco");
define("_INVALIDHITS","Nmeros devem ser um inteiro positivo");
define("_CHECKNAME","Voc deve informar seu Nome e Email");
define("_INVALIDEMAIL","Email Invlido (ex: voc@hotmail.com)");
define("_INVALIDLINK","Voc deve informar o ttulo do link e um link relacionado ou deixar ambos dos espaos em branco");
define("_ADDED","Adicionar:");
define("_REVIEWER","Revisor:");
define("_REVIEWID","ID da Reviso");
define("_HITS","Hits");
define("_LOOKSRIGHT","Parece correto?");
define("_RMODIFIED","modificado");
define("_RADDED","Adicionado");
define("_ADMINLOGGED","Atualmente a Administrao est conectada...esta reviso ser imediata");
define("_RTHANKS","Obrigado por enviar esta reviso");
define("_MODIFICATION","modificao");
define("_ISAVAILABLE","Est agora disponvel no banco de dados de modificao.");
define("_EDITORWILLLOOK","O site vai olhar sua emisso. E ela logo estar disponvel!");
define("_RBACK","Voltar ao ndice de Revises");
define("_RWELCOME","Bem-Vindo a Seo de Reviso");
define("_10MOSTPOP","As 10 primeiras revises");
define("_10MOSTREC","As 10 mais recentes revises");
define("_THEREARE","H");
define("_REVIEWSINDB","Revises no Banco de Dados");
define("_REVIEWS","Reviso");
define("_REVIEWSLETTER","Revises para carta");
define("_NOREVIEWS","Nem todas as revises so para carta");
define("_TOTALREVIEWS","Total de Reviso(es) encontrada(s).");
define("_RETURN2MAIN","Retornar ao Menu Principal");
define("_REVIEWCOMMENT","Faa um Comentrio sobre a Reviso:");
define("_YOURNICK","Seu Nome:");
define("_RCREATEACCOUNT","<a href=modules.php?name=Your_Account>Crie</a> uma conta");
define("_YOURCOMMENT","Seu Comentrio:");
define("_MYSCORE","Minha Pontuao:");
define("_REVIEWMOD","Reviso Modificada");
define("_RDATE","Data:");
define("_RTITLE","Ttulo:");
define("_RTEXT","Texto:");
define("_REVEMAIL","Email:");
define("_RLINK","Link:");
define("_RLINKTITLE","Ttulo do Link:");
define("_COVERIMAGE","Imagem Correspondente:");
define("_PREMODS","Visualizar Modificaes");
define("_PAGE","Pginas");
define("_PAGEBREAK","Se voc quer escrever muito textos voc pode <b>&lt;!--pagebreak--&gt;</b> escrever um texto em partes.");
define("_PREVIEW","Pr-Visualizao");
define("_LANGUAGE","Language");

?>

==> phpnuke-5.6.tgz: www/phpnuke/html/modules/Reviews/language/lang-brazilian.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please go to the site and send to me        */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_PREVIOUS","Pgina Anterior");
define("_NEXT","Pgina Posterior");
define("_YOURNAME","Seu Nome");
define("_SORTASC","Ordem Crescente");
define("_SORTDESC","Ordem Decrescente");
define("_CANCEL","Cancela");
define("_YES","Sim");
define("_NO","No");
define("_SCORE","Pontos:");
define("_REPLYMAIN","Enviar Comentrio");
define("_ALLOWEDHTML","HTML Permitido:");
define("_POSTANON","Enviar como Annimo");
define("_WRITEREVIEW","Escreva uma Reviso");
define("_WRITEREVIEWFOR","Escreva uma Reviso para");
define("_ENTERINFO","Por favor entre com as informaes de acordo com as especificaes");
define("_PRODUCTTITLE","Ttulo do Produto");
define("_NAMEPRODUCT","Nome do Produto Revisado.");
define("_REVIEW","Reviso");
define("_CHECKREVIEW","Sua Reviso atual. Por favor observe a gramtica correta! Faa isto com pelo menos 100 palavras, OK? Voc pode usar cdigo HTML e suas codificaes se souber usar.");
define("_FULLNAMEREQ","Seu Nome Completo. Obrigatrio.");
define("_REMAIL","Seu Email");
define("_REMAILREQ","Seu Endereo de Email . Obrigatrio.");
define("_SELECTSCORE","Pontuao deste Produto");
define("_RELATEDLINK","Link Relacionado");
define("_PRODUCTSITE","Website oficial do produto. Confira se o endereo comea mesmo com \"http://\"");
define("_LINKTITLE","Ttulo do Link ");
define("_LINKTITLEREQ","Requirido se voc tem um site relacionado, caso contrrio  opcional.");
define("_RIMAGEFILE","Nome da Figura");
define("_RIMAGEFILEREQ","Nome da imagem correspondente, localizada em images/reviews. No Obrigatrio");
define("_CHECKINFO","Por favor tenha certeza que a informao que voc entrou  100% correta e esta com a gramtica correta. Por exemplo, por favor no exagere com seu texto ou ele ser rejeitado.");
define("_INVALIDTITLE","Ttulo Invlido...No pode estar em branco");
define("_INVALIDSCORE","Pontuao Invlida...Deve ser entre 1 e 10");
define("_INVALIDTEXT","Texto Reviso Invlido...No pode estar em branco");
define("_INVALIDHITS","Nmeros devem ser um inteiro positivo");
define("_CHECKNAME","Voc deve informar seu Nome e Email");
define("_INVALIDEMAIL","Email Invlido (ex: voc@hotmail.com)");
define("_INVALIDLINK","Voc deve informar o ttulo do link e um link relacionado ou deixar ambos dos espaos em branco");
define("_ADDED","Adicionar:");
define("_REVIEWER","Revisor:");
define("_REVIEWID","ID da Reviso");
define("_HITS","Hits");
define("_LOOKSRIGHT","Parece correto?");
define("_RMODIFIED","modificado");
define("_RADDED","Adicionado");
define("_ADMINLOGGED","Atualmente a Administrao est conectada...esta reviso ser imediata");
define("_RTHANKS","Obrigado por enviar esta reviso");
define("_MODIFICATION","modificao");
define("_ISAVAILABLE","Est agora disponvel no banco de dados de modificao.");
define("_EDITORWILLLOOK","O site vai olhar sua emisso. E ela logo estar disponvel!");
define("_RBACK","Voltar ao ndice de Revises");
define("_RWELCOME","Bem-Vindo a Seo de Reviso");
define("_10MOSTPOP","As 10 primeiras revises");
define("_10MOSTREC","As 10 mais recentes revises");
define("_THEREARE","H");
define("_REVIEWSINDB","Revises no Banco de Dados");
define("_REVIEWS","Reviso");
define("_REVIEWSLETTER","Revises para carta");
define("_NOREVIEWS","Nem todas as revises so para carta");
define("_TOTALREVIEWS","Total de Reviso(es) encontrada(s).");
define("_RETURN2MAIN","Retornar ao Menu Principal");
define("_REVIEWCOMMENT","Faa um Comentrio sobre a Reviso:");
define("_YOURNICK","Seu Nome:");
define("_RCREATEACCOUNT","<a href=modules.php?name=Your_Account>Crie</a> uma conta");
define("_YOURCOMMENT","Seu Comentrio:");
define("_MYSCORE","Minha Pontuao:");
define("_REVIEWMOD","Reviso Modificada");
define("_RDATE","Data:");
define("_RTITLE","Ttulo:");
define("_RTEXT","Texto:");
define("_REVEMAIL","Email:");
define("_RLINK","Link:");
define("_RLINKTITLE","Ttulo do Link:");
define("_COVERIMAGE","Imagem Correspondente:");
define("_PREMODS","Visualizar Modificaes");
define("_PAGE","Pginas");
define("_PAGEBREAK","Se voc quer escrever muito textos voc pode <b>&lt;!--pagebreak--&gt;</b> escrever um texto em partes.");
define("_PREVIEW","Pr-Visualizao");
define("_LANGUAGE","Language");

?>
